@@ -391,6 +391,8 @@ from .snappi_convergence import ConvergenceRequest
 from .snappi_convergence import FlowMetricsRequest
 from .snappi_convergence import FlowMetricGroupRequest
 from .snappi_convergence import ConvergenceFlowRequest
+from .snappi_convergence import Bgpv4MetricsRequest
+from .snappi_convergence import Bgpv6MetricsRequest
 from .snappi_convergence import ConvergenceResponse
 from .snappi_convergence import FlowMetric
 from .snappi_convergence import FlowMetricGroup
@@ -402,6 +404,10 @@ from .snappi_convergence import ConvergenceFlow
 from .snappi_convergence import ConvergenceEvent
 from .snappi_convergence import ConvergenceEventIter
 from .snappi_convergence import ConvergenceFlowIter
+from .snappi_convergence import Bgpv4Metric
+from .snappi_convergence import Bgpv4MetricIter
+from .snappi_convergence import Bgpv6Metric
+from .snappi_convergence import Bgpv6MetricIter
 from .snappi_convergence import Api
 from .snappi_convergence import HttpApi
 from .snappi_convergence import api
